Crate kcr_workloads_kubeblocks_io

Crate kcr_workloads_kubeblocks_io 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the workloads.kubeblocks.io group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

workloads.kubeblocks.io/v1

  • InstanceSet

workloads.kubeblocks.io/v1alpha1

  • InstanceSet
  • ReplicatedStateMachine

Modules

v1
v1alpha1